[Scummvm-git-logs] scummvm master -> 864cdd85f483824e765a4b35d658ef4c2f4506df

athrxx athrxx at scummvm.org
Fri Mar 22 21:18:01 CET 2019


This automated email contains information about 3 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
73678257b9 AUDIO: (FM-TOWNS) - turn warning into debug message
1cfa6c087a AUDIO: (FM-TOWNS/PC-98) - silence some compiler warnings
864cdd85f4 KYRA: silence some compiler warnings


Commit: 73678257b95f49319f7789943e4a8b1855e18c8b
    https://github.com/scummvm/scummvm/commit/73678257b95f49319f7789943e4a8b1855e18c8b
Author: athrxx (athrxx at scummvm.org)
Date: 2019-03-22T21:03:53+01:00

Commit Message:
AUDIO: (FM-TOWNS) - turn warning into debug message

(no need to bother users with something that is actually intended behavior)

Changed paths:
    audio/softsynth/fmtowns_pc98/towns_audio.cpp


diff --git a/audio/softsynth/fmtowns_pc98/pc98_audio.cpp b/audio/softsynth/fmtowns_pc98/pc98_audio.cpp
index d6c6fc9..3ad1009 100644
--- a/audio/softsynth/fmtowns_pc98/pc98_audio.cpp
+++ b/audio/softsynth/fmtowns_pc98/pc98_audio.cpp
@@ -61,8 +61,6 @@ private:
 	const uint16 _port1, _port2, _port3, _port4;
 	uint8 _address[2];
 
-	uint16 _frequency;
-	
 	PC98AudioPluginDriver *_drv;
 	void *_drvOwner;
 	bool _ready;
@@ -77,8 +75,8 @@ PC98AudioCoreInternal::PC98AudioCoreInternal(Audio::Mixer *mixer, PC98AudioCore
 	_musicVolume(Audio::Mixer::kMaxMixerVolume), _sfxVolume(Audio::Mixer::kMaxMixerVolume),
 	_port1(type == PC98AudioPluginDriver::kTypeTowns ? 0x4D8 : 0x188), _port2(type == PC98AudioPluginDriver::kTypeTowns ? 0x4DA : 0x18A),
 	_port3(type == PC98AudioPluginDriver::kTypeTowns ? 0x4DC : 0x18C), _port4(type == PC98AudioPluginDriver::kTypeTowns ? 0x4DE : 0x18E),
-	_frequency(0), _ready(false) {
-	_address[0] = _address[1] = 0xFF;
+	_ready(false) {
+		_address[0] = _address[1] = 0xFF;
 }
 
 PC98AudioCoreInternal::~PC98AudioCoreInternal() {
@@ -287,4 +285,4 @@ PC98AudioCore::MutexLock::MutexLock(PC98AudioCoreInternal *pc98int) : _pc98int(p
 PC98AudioCore::MutexLock::~MutexLock() {
 	if (_pc98int)
 		_pc98int->mutex().unlock();
-}
\ No newline at end of file
+}
diff --git a/audio/softsynth/fmtowns_pc98/towns_pc98_driver.cpp b/audio/softsynth/fmtowns_pc98/towns_pc98_driver.cpp
index b5e8c84..ed1b851 100644
--- a/audio/softsynth/fmtowns_pc98/towns_pc98_driver.cpp
+++ b/audio/softsynth/fmtowns_pc98/towns_pc98_driver.cpp
@@ -184,8 +184,6 @@ private:
 	bool control_f1_prcStart(uint8 para);
 	bool control_ff_endOfTrack(uint8 para);
 
-	uint8 _algorithm;
-
 	typedef Common::Functor1Mem<uint8, bool, TownsPC98_MusicChannelPCM> ControlEvent;
 	Common::Array<const ControlEvent*> _controlEvents;
 };
@@ -983,7 +981,7 @@ void TownsPC98_SfxChannel::reset() {
 #ifndef DISABLE_PC98_RHYTHM_CHANNEL
 #define CONTROL(x) _controlEvents.push_back(new ControlEvent(this, &TownsPC98_MusicChannelPCM::control_##x))
 TownsPC98_MusicChannelPCM::TownsPC98_MusicChannelPCM(TownsPC98_AudioDriver *driver, uint8 regOffs, uint8 flgs, uint8 num, uint8 key, uint8 prt, uint8 id) :
-TownsPC98_MusicChannel(driver, regOffs, flgs, num, key, prt, id), _algorithm(0x80) {
+TownsPC98_MusicChannel(driver, regOffs, flgs, num, key, prt, id) {
 	CONTROL(dummy);
 	CONTROL(f1_prcStart);
 	CONTROL(dummy);
diff --git a/audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h b/audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h
index 58b7ccb..0c4a778 100644
--- a/audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h
+++ b/audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h
@@ -142,8 +142,6 @@ private:
 	int32 *_oprLevelOut;
 	int32 *_oprDetune;
 
-	bool _regProtectionFlag;
-
 	typedef void (TownsPC98_FmSynth::*ChipTimerProc)();
 	void idleTimerCallback() {}
 


Commit: 864cdd85f483824e765a4b35d658ef4c2f4506df
    https://github.com/scummvm/scummvm/commit/864cdd85f483824e765a4b35d658ef4c2f4506df
Author: athrxx (athrxx at scummvm.org)
Date: 2019-03-22T21:03:54+01:00

Commit Message:
KYRA: silence some compiler warnings

Changed paths:
    engines/kyra/detection.cpp
    engines/kyra/gui/debugger.cpp
    engines/kyra/resource/staticres_eob.cpp


diff --git a/engines/kyra/detection.cpp b/engines/kyra/detection.cpp
index a26c52a..75d608d 100644
--- a/engines/kyra/detection.cpp
+++ b/engines/kyra/detection.cpp
@@ -245,7 +245,7 @@ bool KyraMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGame
 		 if (Common::parseRenderMode(ConfMan.get("render_mode")) == Common::kRenderEGA)
 			 flags.useHiRes = true;
 		 if (platform == Common::kPlatformFMTowns && !flags.useHiColorMode)
-			 error("EOB ÌI FM-TOWNS requires support of 16bit color modes which has not been activated in your ScummVM build (The 'USE_RGB_COLOR' define has not been set).");
+			 error("EOB II FM-TOWNS requires support of 16bit color modes which has not been activated in your ScummVM build (The 'USE_RGB_COLOR' define has not been set).");
 		*engine = new Kyra::DarkMoonEngine(syst, flags);
 		break;
 #endif // ENABLE_EOB
diff --git a/engines/kyra/gui/debugger.cpp b/engines/kyra/gui/debugger.cpp
index f8fa7f8..2003c2f 100644
--- a/engines/kyra/gui/debugger.cpp
+++ b/engines/kyra/gui/debugger.cpp
@@ -642,7 +642,7 @@ bool Debugger_EoB::cmdPrintMap(int, const char **) {
 		if (s == 3 || s == 4)
 			c = '/';
 		else if (s == 2 || s == 8)
-			c = (uint8)'°';
+			c = 176;
 		else if (f & 8)
 			c = 216;
 		else if (f & 1)
@@ -661,7 +661,7 @@ bool Debugger_EoB::cmdPrintMap(int, const char **) {
 		
 		debugPrintf("%c", c);
 	}
-	debugPrintf("\n\nParty Position:   %c  Door:             %c  Stairs Up/Down: %c/%c  Plate:      %c   Hole: %c\nSwitch:           %c  Clickable Object: %c  Illusion Wall:  %c    Teleporter: %c\n\n", 'X', 216, 'U', 'D', 'O', 164, '/', '°', 15, 1);
+	debugPrintf("\n\nParty Position:   %c  Door:             %c  Stairs Up/Down: %c/%c  Plate:      %c   Hole: %c\nSwitch:           %c  Clickable Object: %c  Illusion Wall:  %c    Teleporter: %c\n\n", 'X', 216, 'U', 'D', 'O', 164, '/', 176, 15, 1);
 
 	return true;
 }
diff --git a/engines/kyra/resource/staticres_eob.cpp b/engines/kyra/resource/staticres_eob.cpp
index a9f9c33..7ff439d 100644
--- a/engines/kyra/resource/staticres_eob.cpp
+++ b/engines/kyra/resource/staticres_eob.cpp
@@ -511,11 +511,12 @@ void EoBCoreEngine::initStaticResource() {
 	// EOB I doesn't have load and save menus, because there is only one single
 	// save slot. Instead of emulating this we provide a menu similiar to EOB II.
 
-	static const char *const saveLoadStrings[4][4] = {
+	static const char *const saveLoadStrings[5][4] = {
 		{   "Cancel",   "Empty Slot",		"Save Game",    "Load Game"     },
 		{   "Abbr.",    "Leerer Slot",		"Speichern",    "  Laden"       },
 		{	" < < ",	"Posizione Vuota",	"Salva",		"Carica"	    },
-		{   0,          0,					0,					0			}
+		{   0,          0,					0,					0			},
+		{	0,          0,					0,					0			}
 	};
 
 	static const char *const errorSlotEmptyString[5] = {





More information about the Scummvm-git-logs mailing list
diff --git a/audio/softsynth/fmtowns_pc98/towns_audio.cpp b/audio/softsynth/fmtowns_pc98/towns_audio.cpp
index 7d61631..937b9bd 100644
--- a/audio/softsynth/fmtowns_pc98/towns_audio.cpp
+++ b/audio/softsynth/fmtowns_pc98/towns_audio.cpp
@@ -23,6 +23,7 @@
 #include "audio/softsynth/fmtowns_pc98/towns_audio.h"
 #include "audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h"
 
+#include "common/debug.h"
 #include "common/endian.h"
 #include "common/util.h"
 #include "common/textconsole.h"
@@ -730,8 +731,8 @@ int TownsAudioInterfaceInternal::intf_loadSamples(va_list &args) {
 	if (size + dest > 65536)
 		// EOB II FM-TOWNS tries to load more than 65536 bytes of wave sounds for the outro sequence.
 		// This means that some sfx would not play. Since we don't really need the memory limit,
-		// I have commented out the error return and added a warning instead.
-		warning("FM-TOWNS AUDIO: exceeding wave memory size by %d bytes", size + dest - 65536);
+		// I have commented out the error return and added a debug message instead.
+		debugN(9, "FM-TOWNS AUDIO: exceeding wave memory size by %d bytes", size + dest - 65536);
 		// return 5;
 
 	int dwIndex = _numWaveTables - 1;


Commit: 1cfa6c087a88eb795dc0ae46cbeb5a578318a317
    https://github.com/scummvm/scummvm/commit/1cfa6c087a88eb795dc0ae46cbeb5a578318a317
Author: athrxx (athrxx at scummvm.org)
Date: 2019-03-22T21:03:54+01:00

Commit Message:
AUDIO: (FM-TOWNS/PC-98) - silence some compiler warnings

Changed paths:
    audio/softsynth/fmtowns_pc98/pc98_audio.cpp
    audio/softsynth/fmtowns_pc98/towns_pc98_driver.cpp
    audio/softsynth/fmtowns_pc98/towns_pc98_fmsynth.h

